summaryrefslogtreecommitdiff
path: root/notes-merge.h
diff options
context:
space:
mode:
Diffstat (limited to 'notes-merge.h')
-rw-r--r--notes-merge.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/notes-merge.h b/notes-merge.h
index 0d89056..f815f23 100644
--- a/notes-merge.h
+++ b/notes-merge.h
@@ -32,16 +32,16 @@ void init_notes_merge_options(struct notes_merge_options *o);
* outcomes:
*
* 1. The merge trivially results in an existing commit (e.g. fast-forward or
* already-up-to-date). 'local_tree' is untouched, the SHA1 of the result
* is written into 'result_sha1' and 0 is returned.
* 2. The merge successfully completes, producing a merge commit. local_tree
* contains the updated notes tree, the SHA1 of the resulting commit is
* written into 'result_sha1', and 1 is returned.
* 3. The merge results in conflicts. This is similar to #2 in that the
* partial merge result (i.e. merge result minus the unmerged entries)
* are stored in 'local_tree', and the SHA1 or the resulting commit
* (to be amended when the conflicts have been resolved) is written into
* 'result_sha1'. The unmerged entries are written into the
* .git/NOTES_MERGE_WORKTREE directory with conflict markers.
* -1 is returned.
*
@@ -52,7 +52,7 @@ void init_notes_merge_options(struct notes_merge_options *o);
*/
int notes_merge(struct notes_merge_options *o,
struct notes_tree *local_tree,
- unsigned char *result_sha1);
+ struct object_id *result_oid);
/*
* Finalize conflict resolution from an earlier notes_merge()
@@ -62,13 +62,13 @@ int notes_merge(struct notes_merge_options *o,
* call to notes_merge().
*
* This function will add the (now resolved) notes in .git/NOTES_MERGE_WORKTREE
* to 'partial_tree', and create a final notes merge commit, the SHA1 of which
* will be stored in 'result_sha1'.
*/
int notes_merge_commit(struct notes_merge_options *o,
struct notes_tree *partial_tree,
struct commit *partial_commit,
- unsigned char *result_sha1);
+ struct object_id *result_oid);
/*
* Abort conflict resolution from an earlier notes_merge()
@@ -32,16 +32,16 @@ void init_notes_merge_options(struct notes_merge_options *o);
*
* 1. The merge trivially results in an existing commit (e.g. fast-forward or
- * already-up-to-date). 'local_tree' is untouched, the SHA1 of the result
- * is written into 'result_sha1' and 0 is returned.
+ * already-up-to-date). 'local_tree' is untouched, the OID of the result
+ * is written into 'result_oid' and 0 is returned.
* 2. The merge successfully completes, producing a merge commit. local_tree
@@ -32,16 +32,16 @@ void init_notes_merge_options(struct notes_merge_options *o);
* 2. The merge successfully completes, producing a merge commit. local_tree
- * contains the updated notes tree, the SHA1 of the resulting commit is
- * written into 'result_sha1', and 1 is returned.
+ * contains the updated notes tree, the OID of the resulting commit is
+ * written into 'result_oid', and 1 is returned.
* 3. The merge results in conflicts. This is similar to #2 in that the
* partial merge result (i.e. merge result minus the unmerged entries)
@@ -32,16 +32,16 @@ void init_notes_merge_options(struct notes_merge_options *o);
* 3. The merge results in conflicts. This is similar to #2 in that the
* partial merge result (i.e. merge result minus the unmerged entries)
- * are stored in 'local_tree', and the SHA1 or the resulting commit
+ * are stored in 'local_tree', and the OID or the resulting commit
* (to be amended when the conflicts have been resolved) is written into
@@ -32,16 +32,16 @@ void init_notes_merge_options(struct notes_merge_options *o);
* (to be amended when the conflicts have been resolved) is written into
- * 'result_sha1'. The unmerged entries are written into the
+ * 'result_oid'. The unmerged entries are written into the
* .git/NOTES_MERGE_WORKTREE directory with conflict markers.
* -1 is returned.
@@ -62,13 +62,13 @@ int notes_merge(struct notes_merge_options *o,
*
* This function will add the (now resolved) notes in .git/NOTES_MERGE_WORKTREE
- * to 'partial_tree', and create a final notes merge commit, the SHA1 of which
- * will be stored in 'result_sha1'.
+ * to 'partial_tree', and create a final notes merge commit, the OID of which
+ * will be stored in 'result_oid'.
*/
int notes_merge_commit(struct notes_merge_options *o,